summaryrefslogtreecommitdiff
path: root/chromium/third_party/metrics_proto
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2019-05-16 09:59:13 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2019-05-20 10:28:53 +0000
commit6c11fb357ec39bf087b8b632e2b1e375aef1b38b (patch)
treec8315530db18a8ee566521c39ab8a6af4f72bc03 /chromium/third_party/metrics_proto
parent3ffaed019d0772e59d6cdb2d0d32fe4834c31f72 (diff)
downloadqtwebengine-chromium-6c11fb357ec39bf087b8b632e2b1e375aef1b38b.tar.gz
BASELINE: Update Chromium to 74.0.3729.159
Change-Id: I8d2497da544c275415aedd94dd25328d555de811 Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/third_party/metrics_proto')
-rw-r--r--chromium/third_party/metrics_proto/README.chromium4
-rw-r--r--chromium/third_party/metrics_proto/cast_logs.proto3
-rw-r--r--chromium/third_party/metrics_proto/omnibox_event.proto11
-rw-r--r--chromium/third_party/metrics_proto/sampled_profile.proto18
-rw-r--r--chromium/third_party/metrics_proto/ukm/source.proto19
5 files changed, 43 insertions, 12 deletions
diff --git a/chromium/third_party/metrics_proto/README.chromium b/chromium/third_party/metrics_proto/README.chromium
index 5c7c56693df..ee80601c7a5 100644
--- a/chromium/third_party/metrics_proto/README.chromium
+++ b/chromium/third_party/metrics_proto/README.chromium
@@ -1,8 +1,8 @@
Name: Metrics Protos
Short Name: metrics_proto
URL: This is the canonical public repository
-Version: 229533285
-Date: 2019/01/16 UTC
+Version: 236649832
+Date: 2019/03/04 UTC
License: BSD
Security Critical: Yes
diff --git a/chromium/third_party/metrics_proto/cast_logs.proto b/chromium/third_party/metrics_proto/cast_logs.proto
index 2a9e37c5fe8..9d43c07791c 100644
--- a/chromium/third_party/metrics_proto/cast_logs.proto
+++ b/chromium/third_party/metrics_proto/cast_logs.proto
@@ -240,7 +240,7 @@ message CastLogsProto {
// Next tag: 9
message CastDeviceMutableInfo {
// This is the last type of reboot the device encountered
- // Next tag: 11
+ // Next tag: 12
enum RebootType {
REBOOT_TYPE_UNKNOWN = 0; // Fail to get reboot type from system property
REBOOT_TYPE_FORCED = 1; // Power removed from device
@@ -253,6 +253,7 @@ message CastLogsProto {
REBOOT_TYPE_FDR = 8;
REBOOT_TYPE_HW_WATCHDOG = 9;
REBOOT_TYPE_SW_OTHER = 10;
+ REBOOT_TYPE_OVERHEAT = 11;
}
optional RebootType last_reboot_type = 1;
diff --git a/chromium/third_party/metrics_proto/sampled_profile.proto b/chromium/third_party/metrics_proto/sampled_profile.proto
index ea29b73a376..5cf56501f00 100644
--- a/chromium/third_party/metrics_proto/sampled_profile.proto
+++ b/chromium/third_party/metrics_proto/sampled_profile.proto
@@ -11,15 +11,15 @@ option java_package = "org.chromium.components.metrics";
package metrics;
+import "call_stack_profile.proto";
import "execution_context.proto";
import "perf_data.proto";
import "perf_stat.proto";
-import "call_stack_profile.proto";
// Protocol buffer for collected sample-based profiling data.
// Contains the parameters and data from a single profile collection event.
-// Next tag: 13
+// Next tag: 15
message SampledProfile {
// Indicates the event that triggered this collection.
enum TriggerEvent {
@@ -60,6 +60,20 @@ message SampledProfile {
// The thread in which the profile was collected.
optional Thread thread = 12;
+ // Map of Chrome PIDs running on the system when the profile was collected.
+ // Each Chrome PID is mapped to its process type.
+ // This field and the below thread_types field assume that the PID/TID
+ // information are collected in a short duration for a single session such
+ // that, the PID/TID reuse is highly unlikely.
+ // The information from these two fields is used to map chrome samples
+ // collected for a specific PID/TID to the corresponding process type and
+ // thread type.
+ map<uint32, Process> process_types = 13;
+
+ // Map of Chrome TIDs running on the system when the profile was collected.
+ // Each Chrome TID is mapped to its thread type.
+ map<uint32, Thread> thread_types = 14;
+
// Fields 2-3: Time durations are given in ticks, and represent system uptime
// rather than wall time.
diff --git a/chromium/third_party/metrics_proto/ukm/source.proto b/chromium/third_party/metrics_proto/ukm/source.proto
index f9fdba3a789..93105d32ed3 100644
--- a/chromium/third_party/metrics_proto/ukm/source.proto
+++ b/chromium/third_party/metrics_proto/ukm/source.proto
@@ -9,7 +9,7 @@ option optimize_for = LITE_RUNTIME;
package ukm;
// Source contains data related to a top-level navigation.
-// Next tag: 13
+// Next tag: 15
message Source {
// The URL scheme, such as HTTP, HTTPS, CHROME_EXTENSION, etc.
enum UrlScheme {
@@ -26,10 +26,18 @@ message Source {
// An identifier for the source. This should be unique within a session.
optional int64 id = 1;
- // The previous source id for the tab this source is in. Should only be set
- // for navigation sources.
+ // The previous source id for the tab this source is in. Should only
+ // be set for navigation sources. Note that only non-same-document
+ // sources are included here. If you want to include same-document
+ // navigations, use previous_same_document_source_id.
optional int64 previous_source_id = 11;
+ // The source id for the previous same document navigation, if the
+ // previously committed source was a same document navigation. If
+ // the previously committed source was not a same document
+ // navigation, this field will be unset.
+ optional int64 previous_same_document_source_id = 14;
+
// For sources representing the first navigation in a new tab, this id marks
// the source which opened the tab. Should only be set for the first
// navigation source in a tab.
@@ -51,6 +59,11 @@ message Source {
// or partial redirect chains for main frame navigations.
repeated UrlInfo urls = 8;
+ // Whether this source is for a same document navigation. Examples of same
+ // document navigations are fragment navigations, pushState/replaceState,
+ // and same page history navigation.
+ optional bool is_same_document_navigation = 13;
+
// The URL of the source, as recorded in history. If this URL has not been
// discovered by Google's crawler, it should not be recorded.
optional string url = 2;
diff --git a/chromium/third_party/metrics_proto/omnibox_event.proto b/chromium/third_party/metrics_proto/omnibox_event.proto
index f23f03fb042..2daebc5510f 100644
--- a/chromium/third_party/metrics_proto/omnibox_event.proto
+++ b/chromium/third_party/metrics_proto/omnibox_event.proto
@@ -193,10 +193,13 @@ message OmniboxEventProto {
// This enum value is currently only used by Android GSA. It represents
// a suggestion powered by a Chrome content provider.
ON_DEVICE_CHROME = 13;
- CLIPBOARD_URL = 14; // Suggestion coming from clipboard.
- PHYSICAL_WEB = 15; // DEPRECATED. Suggestions triggered by URLs broadcast
- // by nearby devices.
- DOCUMENT = 16; // Suggestions for documents in a cloud corpus.
+ CLIPBOARD = 14; // Suggestion coming from clipboard.
+ PHYSICAL_WEB = 15; // DEPRECATED. Suggestions triggered by URLs broadcast
+ // by nearby devices.
+ DOCUMENT = 16; // Suggestions for documents in a cloud corpus.
+ // Non personalized query suggestions generated from a lightweight on device
+ // head model.
+ ON_DEVICE_HEAD = 17;
}
// The result set displayed on the completion popup